pub struct VdCorput { /* private fields */ }Expand description
van der Corput sequence generator
Generates the van der Corput sequence, a low-discrepancy sequence commonly used in quasi-Monte Carlo methods. The sequence is generated by iterating over a base and calculating the fractional part of the number in that base.
The radical inverse process reverses the base-$$b$$ digits of the integer. For example, $$n = 13 = 1101_2$$, reversed digits give $$\phi_2(13) = 0.1011_2 = 0.6875$$.
Examples
use lds_rs::VdCorput;
let mut vgen = VdCorput::new(2);
vgen.reseed(0);
assert_eq!(vgen.pop(), 0.5);
assert_eq!(vgen.pop(), 0.25);
assert_eq!(vgen.pop(), 0.75);Implementations
Sourceimpl VdCorput
impl VdCorput
Sourcepub fn new(base: u64) -> Self
pub fn new(base: u64) -> Self
Creates a new van der Corput sequence generator with the given base
Arguments
base- The base of the number system (defaults to 2 if not specified)
Sourcepub fn pop(&mut self) -> f64
pub fn pop(&mut self) -> f64
Generates the next value in the sequence
$$ \phi_b(n) = \sum_{k=0}^{m} \frac{d_k}{b^{k+1}} $$
Increments the count and calculates the van der Corput sequence value for that count and base.
Sourcepub fn peek(&self) -> f64
pub fn peek(&self) -> f64
Returns the next value without advancing the state (peek)
$$ \phi_b(n) = \sum_{k=0}^{m} \frac{d_k}{b^{k+1}} $$
Allows looking at the next value in the sequence without consuming it.